@@ -1,17 +1,15 @@
 import os
-import numpy as np
-from numpy.testing import assert_array_equal, assert_equal, assert_raises
-from nose.tools import ok_
 from pathlib import Path
 
+import numpy as np
+from morphio import MitochondriaPointLevel
+from morphio import Morphology as ImmutMorphology
+from morphio import PointLevel, SectionBuilderError, SectionType, WriterError, ostream_redirect
 from morphio.mut import Morphology
-from morphio import (SectionBuilderError, set_maximum_warnings, SectionType, PointLevel,
-                     WriterError,
-                     MitochondriaPointLevel, Morphology as ImmutMorphology, ostream_redirect)
+from nose.tools import ok_
+from numpy.testing import assert_array_equal, assert_equal, assert_raises
 
-from . utils import captured_output, setup_tempdir, assert_string_equal
-
-_path = os.path.join(os.path.dirname(os.path.abspath(__file__)), "data")
+from .utils import assert_string_equal, captured_output, setup_tempdir
 
 
 def test_write_empty_file():
@@ -20,7 +18,7 @@ def test_write_empty_file():
         with ostream_redirect(stdout=True, stderr=True):
             with setup_tempdir('test_write_empty_file', no_cleanup=True) as tmp_folder:
                 for ext in ['asc', 'swc', 'h5']:
-                    outname = os.path.join(tmp_folder, 'empty.' + ext)
+                    outname = Path(tmp_folder, 'empty.' + ext)
                     Morphology().write(outname)
                     ok_(not os.path.exists(outname))
 
@@ -31,7 +29,7 @@ def test_write_soma_basic():
     morpho.soma.diameters = [2, 3, 3]
 
     with setup_tempdir('test_write_soma_basic') as tmp_folder:
-        morpho.write(os.path.join(tmp_folder, "test_write.swc"))
+        morpho.write(Path(tmp_folder, "test_write.swc"))
         morpho.write(Path(tmp_folder, "test_write_pathlib.swc"))
         assert_equal(len(os.listdir(tmp_folder)), 2)
 
@@ -62,17 +60,19 @@ def test_write_basic():
                                             [2, 4]))
 
     with setup_tempdir('test_write_basic') as tmp_folder:
-        morpho.write(os.path.join(tmp_folder, "test_write.asc"))
-        morpho.write(os.path.join(tmp_folder, "test_write.swc"))
-        h5_out = os.path.join(tmp_folder, "test_write.h5")
+        morpho.write(Path(tmp_folder, "test_write.asc"))
+        morpho.write(Path(tmp_folder, "test_write.swc"))
+        h5_out = Path(tmp_folder, "test_write.h5")
         morpho.write(h5_out)
 
         expected = [[0., 0., 0.], [0., 5., 0.], [0., 5., 0.], [-5., 5., 0.],
                     [0., 5., 0.], [6., 5., 0.], [0., 0., 0.], [0., -4., 0.],
                     [0., -4., 0.], [6., -4., 0.], [0., -4., 0.], [-5., -4., 0.]]
-        assert_array_equal(ImmutMorphology(os.path.join(tmp_folder, "test_write.asc")).points, expected)
-        assert_array_equal(ImmutMorphology(os.path.join(tmp_folder, "test_write.swc")).points, expected)
-        assert_array_equal(ImmutMorphology(os.path.join(tmp_folder, "test_write.h5")).points, expected)
+        assert_array_equal(ImmutMorphology(Path(tmp_folder, "test_write.asc")).points, expected)
+        assert_array_equal(ImmutMorphology(Path(tmp_folder, "test_write.swc")).points, expected)
+        h5_morph = ImmutMorphology(Path(tmp_folder, "test_write.h5"))
+        assert_array_equal(h5_morph.points, expected)
+        assert_equal(h5_morph.version, ('h5', 1, 2))
 
         import h5py
         with h5py.File(h5_out, 'r') as h5_file:
@@ -111,7 +111,7 @@ def test_write_merge_only_child():
         for extension in ['swc', 'asc', 'h5']:
             with captured_output() as (_, err):
                 with ostream_redirect(stdout=True, stderr=True):
-                    filename = os.path.join(tmp_folder, 'test.{}'.format(extension))
+                    filename = Path(tmp_folder, 'test.{}'.format(extension))
                     morpho.write(filename)
 
                     assert_equal(err.getvalue().strip(),
@@ -159,7 +159,7 @@ def test_write_perimeter():
                                      [6, 8]))
 
     with setup_tempdir('test_write_perimeter') as tmp_folder:
-        h5_out = os.path.join(tmp_folder, "test_write.h5")
+        h5_out = Path(tmp_folder, "test_write.h5")
         morpho.write(h5_out)
 
         assert_array_equal(ImmutMorphology(h5_out).perimeters,
@@ -167,7 +167,7 @@ def test_write_perimeter():
 
         # Cannot right a morph with perimeter data to ASC and SWC
         for ext in ['swc', 'asc']:
-            out_path = os.path.join(tmp_folder, "test_write_perimeter." + ext)
+            out_path = Path(tmp_folder, "test_write_perimeter." + ext)
             assert_raises(WriterError, morpho.write, out_path)
 
 
@@ -188,7 +188,7 @@ def test_write_no_soma():
         for ext in ['asc', 'h5', 'swc']:
             with captured_output() as (_, err):
                 with ostream_redirect(stdout=True, stderr=True):
-                    outfile = os.path.join(tmp_folder, 'tmp.' + ext)
+                    outfile = Path(tmp_folder, 'tmp.' + ext)
                     morpho.write(outfile)
                     assert_equal(err.getvalue().strip(),
                                  'Warning: writing file without a soma')
@@ -219,23 +219,23 @@ def test_mitochondria():
                                         [0.6, 0.7, 0.8, 0.9],
                                         [20, 30, 40, 50]))
     with setup_tempdir('test_mitochondria') as tmp_folder:
-        morpho.write(os.path.join(tmp_folder, "test.h5"))
+        morpho.write(Path(tmp_folder, "test.h5"))
 
         with captured_output() as (_, err):
             with ostream_redirect(stdout=True, stderr=True):
-                morpho.write(os.path.join(tmp_folder, "test.swc"))
+                morpho.write(Path(tmp_folder, "test.swc"))
                 assert_string_equal(err.getvalue(),
                                     "Warning: this cell has mitochondria, they cannot be saved in "
                                     " ASC or SWC format. Please use H5 if you want to save them.")
 
         with captured_output() as (_, err):
             with ostream_redirect(stdout=True, stderr=True):
-                morpho.write(os.path.join(tmp_folder, "test.asc"))
+                morpho.write(Path(tmp_folder, "test.asc"))
                 assert_string_equal(err.getvalue(),
                                     "Warning: this cell has mitochondria, they cannot be saved in "
                                     " ASC or SWC format. Please use H5 if you want to save them.")
 
-        mito = ImmutMorphology(os.path.join(tmp_folder, 'test.h5')).mitochondria
+        mito = ImmutMorphology(Path(tmp_folder, 'test.h5')).mitochondria
         assert_array_equal(mito.root_sections[0].diameters,
                            diameters)
         assert_array_equal(mito.root_sections[0].neurite_section_ids,
@@ -245,7 +245,7 @@ def test_mitochondria():
 
         assert_equal(len(mito.root_sections), 1)
 
-        mito = Morphology(os.path.join(tmp_folder, 'test.h5')).mitochondria
+        mito = Morphology(Path(tmp_folder, 'test.h5')).mitochondria
         assert_equal(len(mito.root_sections), 1)
         assert_equal(mito.root_sections[0].neurite_section_ids, neuronal_section_ids)
         assert_array_equal(mito.section(0).diameters,
@@ -273,7 +273,7 @@ def test_duplicate_different_diameter():
         for ext in ['asc', 'h5', 'swc']:
             with captured_output() as (_, err):
                 with ostream_redirect(stdout=True, stderr=True):
-                    outfile = os.path.join(tmp_folder, 'tmp.' + ext)
+                    outfile = Path(tmp_folder, 'tmp.' + ext)
                     morpho.write(outfile)
 
                     read = Morphology(outfile)
@@ -297,7 +297,7 @@ def test_single_point_root_section():
             m.append_root_section(PointLevel(points, diameters), SectionType(2))
 
             with setup_tempdir('test_single_point_root_section', no_cleanup=True) as tmp_folder:
-                assert_raises(SectionBuilderError, m.write, os.path.join(tmp_folder, "h5/empty_vasculature.h5"))
+                assert_raises(SectionBuilderError, m.write, Path(tmp_folder, "h5/empty_vasculature.h5"))
 
     m = Morphology()
     points = [[1., 1., 1.]]
@@ -305,4 +305,4 @@ def test_single_point_root_section():
     m.append_root_section(PointLevel(points, diameters), SectionType(2))
 
     with setup_tempdir('test_single_point_root_section', no_cleanup=True) as tmp_folder:
-        assert_raises(SectionBuilderError, m.write, os.path.join(tmp_folder, "h5/empty_vasculature.h5"))
+        assert_raises(SectionBuilderError, m.write, Path(tmp_folder, "h5/empty_vasculature.h5"))
